Welcome to QAlgebra's documentation!
====================================


.. only:: html

   .. image:: https://img.shields.io/badge/qalgebra-qalgebra-blue.svg?logo=github
      :alt: Source code on Github
      :target: https://github.com/qalgebra/qalgebra
   
   .. image:: https://img.shields.io/pypi/v/qalgebra.svg
      :alt: QAlgebra on the Python Package Index
      :target: https://pypi.python.org/pypi/qalgebra
   
   .. image:: https://img.shields.io/badge/Docs-gh--pages-blue.svg 
      :alt: Documentation
      :target: https://qalgebra.github.io/qalgebra/

   .. image:: https://github.com/QAlgebra/qalgebra/workflows/Docs/badge.svg?branch=master
      :alt: Docs
      :target: https://github.com/QAlgebra/qalgebra/actions?query=workflow%3ADocs
   
   .. image:: https://github.com/QAlgebra/qalgebra/workflows/Tests/badge.svg?branch=master
      :alt: Tests
      :target: https://github.com/QAlgebra/qalgebra/actions?query=workflow%3ATests
   
   .. image:: https://img.shields.io/coveralls/github/QAlgebra/qalgebra/master.svg
      :alt: Coveralls
      :target: https://coveralls.io/github/QAlgebra/qalgebra
   
   .. image:: https://img.shields.io/badge/License-MIT-green.svg
      :alt: MIT License
      :target: https://opensource.org/licenses/MIT
   

.. Tutorials (learning oriented):

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   Installation & Usage <readme>
.. tutorial.ipynb


.. Explanation / Discussion (understanding-oriented):

.. toctree::
   :maxdepth: 2
   :caption: Quantum Algebra

   symbolic_algebra
   printing


.. Examples (learning oriented):

.. toctree::
   :maxdepth: 2
   :caption: Examples


.. How-to (problem-oriented):

.. toctree::
   :maxdepth: 2
   :caption: Howtos


.. toctree::
   :maxdepth: 2
   :caption: Development

   contributing
   authors
   history


.. Reference (information oriented):

.. toctree::
   :maxdepth: 1
   :caption: Reference

   library_structure
   API of the QAlgebra package <API/qalgebra>

* :ref:`modindex`
